@@ -21,11 +21,11 @@
 
 static exr_result_t
 print_error_helper (
-    struct _internal_exr_context* pf,
-    exr_result_t                  errcode,
-    DWORD                         dw,
-    exr_stream_error_func_ptr_t   error_cb,
-    const char*                   msg)
+    exr_const_context_t         pf,
+    exr_result_t                errcode,
+    DWORD                       dw,
+    exr_stream_error_func_ptr_t error_cb,
+    const char*                 msg)
 {
     LPVOID   lpMsgBuf;
     LPVOID   lpDisplayBuf;
@@ -60,11 +60,7 @@ print_error_helper (
     }
 
     if (error_cb)
-        error_cb (
-            (exr_const_context_t) pf,
-            errcode,
-            "%s",
-            (const char*) lpDisplayBuf);
+        error_cb (pf, errcode, "%s", (const char*) lpDisplayBuf);
     else
         pf->print_error (pf, errcode, "%s", (const char*) lpDisplayBuf);
 
@@ -75,24 +71,13 @@ print_error_helper (
 }
 
 static exr_result_t
-print_error (
-    struct _internal_exr_context* pf, exr_result_t errcode, const char* msg)
+print_error (exr_const_context_t pf, exr_result_t errcode, const char* msg)
 {
     return print_error_helper (pf, errcode, GetLastError (), NULL, msg);
 }
 
-static exr_result_t
-send_error (
-    struct _internal_exr_context* pf,
-    exr_result_t                  errcode,
-    exr_stream_error_func_ptr_t   error_cb,
-    const char*                   msg)
-{
-    return print_error_helper (pf, errcode, GetLastError (), error_cb, msg);
-}
-
 static wchar_t*
-widen_filename (struct _internal_exr_context* file, const char* fn)
+widen_filename (exr_context_t file, const char* fn)
 {
     int      wcSize = 0, fnlen = 0;
     wchar_t* wcFn = NULL;
@@ -130,7 +115,7 @@ default_shutdown (exr_const_context_t c, void* userdata, int failed)
 /**************************************/
 
 static exr_result_t
-finalize_write (struct _internal_exr_context* pf, int failed)
+finalize_write (exr_context_t pf, int failed)
 {
     /* TODO: Do we actually want to do this or leave the garbage file there */
     if (failed && pf->destroy_fn == &default_shutdown)
@@ -222,7 +207,7 @@ default_read_func (
         if (dw != ERROR_HANDLE_EOF)
         {
             print_error_helper (
-                EXR_CTXT (ctxt),
+                ctxt,
                 EXR_ERR_READ_IO,
                 dw,
                 error_cb,
@@ -290,7 +275,7 @@ default_write_func (
     {
         DWORD dw = GetLastError ();
         print_error_helper (
-            EXR_CTXT (ctxt),
+            ctxt,
             EXR_ERR_READ_IO,
             dw,
             error_cb,
@@ -303,7 +288,7 @@ default_write_func (
 /**************************************/
 
 static exr_result_t
-default_init_read_file (struct _internal_exr_context* file)
+default_init_read_file (exr_context_t file)
 {
     wchar_t*                         wcFn = NULL;
     HANDLE                           fd;
@@ -318,12 +303,16 @@ default_init_read_file (struct _internal_exr_context* file)
     {
 #if defined(_WIN32_WINNT) && (_WIN32_WINNT >= _WIN32_WINNT_WIN8)
         fd = CreateFile2 (
-            wcFn, GENERIC_READ, FILE_SHARE_READ, OPEN_EXISTING, NULL);
+            wcFn,
+            GENERIC_READ,
+            FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
+            OPEN_EXISTING,
+            NULL);
 #else
         fd = CreateFileW (
             wcFn,
             GENERIC_READ,
-            FILE_SHARE_READ,
+            FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
             NULL,
             OPEN_EXISTING,
             FILE_ATTRIBUTE_NORMAL, /* TBD: use overlapped? | FILE_FLAG_OVERLAPPED */
@@ -347,7 +336,7 @@ default_init_read_file (struct _internal_exr_context* file)
 /**************************************/
 
 static exr_result_t
-default_init_write_file (struct _internal_exr_context* file)
+default_init_write_file (exr_context_t file)
 {
     wchar_t*                         wcFn = NULL;
     struct _internal_exr_filehandle* fh   = file->user_data;
@@ -367,14 +356,14 @@ default_init_write_file (struct _internal_exr_context* file)
         fd = CreateFile2 (
             wcFn,
             GENERIC_WRITE | DELETE,
-            0, /* no sharing */
+            FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
             CREATE_ALWAYS,
             NULL);
 #else
         fd = CreateFileW (
             wcFn,
             GENERIC_WRITE | DELETE,
-            0, /* no sharing */
+            FILE_SHARE_READ | FILE_SHARE_WRITE | FILE_SHARE_DELETE,
             NULL,
             CREATE_ALWAYS,
             FILE_ATTRIBUTE_NORMAL, /* TBD: use overlapped? | FILE_FLAG_OVERLAPPED */
@@ -414,7 +403,7 @@ default_query_size_func (exr_const_context_t ctxt, void* userdata)
 /**************************************/
 
 static exr_result_t
-make_temp_filename (struct _internal_exr_context* ret)
+make_temp_filename (exr_context_t ret)
 {
     /* we checked the pointers we care about before calling */
     char        tmproot[32];
